@@ -18,7 +18,8 @@ export function cors(req: Http2ServerRequest, res: Http2ServerResponse): void {
                 if (req.headers['access-control-request-headers']) {
                     res.setHeader('Access-Control-Allow-Headers', req.headers['access-control-request-headers'])
                 }
-                return res.writeHead(200).end()
+                res.writeHead(200).end()
+                return
         }
     }
 }
