@@ -1,6 +1,8 @@
-import { V1ObjectMeta } from '@kubernetes/client-node'
-import { createResource, listClusterResources } from '../lib/resource-request'
-import { IResource } from './resource'
+/* Copyright Contributors to the Open Cluster Management project */
+
+import { V1ObjectMeta } from '@kubernetes/client-node/dist/gen/model/v1ObjectMeta'
+import { createResource } from '../lib/resource-request'
+import { IResource, IResourceDefinition } from './resource'
 
 export const ProjectApiVersion = 'project.openshift.io/v1'
 export type ProjectApiVersionType = 'project.openshift.io/v1'
@@ -14,12 +16,22 @@ export interface Project extends IResource {
     metadata: V1ObjectMeta
 }
 
+export const ProjectDefinition: IResourceDefinition = {
+    apiVersion: ProjectApiVersion,
+    kind: ProjectKind,
+}
+
 export const ProjectRequestApiVersion = 'project.openshift.io/v1'
 export type ProjectRequestApiVersionType = 'project.openshift.io/v1'
 
 export const ProjectRequestKind = 'ProjectRequest'
 export type ProjectRequestKindType = 'ProjectRequest'
 
+export const ProjectRequestDefinition: IResourceDefinition = {
+    apiVersion: ProjectRequestApiVersion,
+    kind: ProjectRequestKind,
+}
+
 export interface ProjectRequest extends IResource {
     apiVersion: ProjectRequestApiVersionType
     kind: ProjectRequestKindType
@@ -34,10 +46,3 @@ export const createProject = (name: string | undefined) => {
         metadata: { name },
     })
 }
-
-export function listProjects() {
-    return listClusterResources<Project>({
-        apiVersion: ProjectApiVersion,
-        kind: ProjectKind,
-    })
-}
