@@ -15,7 +15,7 @@ import {
     AcmSelect,
     AcmSubmit,
     Provider,
-} from '@open-cluster-management/ui-components'
+} from '@stolostron/ui-components'
 import {
     ActionGroup,
     ButtonVariant,
